@@ -23,24 +23,33 @@ pub use cl_sys::{
 
 use super::error_codes::{CL_INVALID_VALUE, CL_SUCCESS};
 use super::info_type::InfoType;
+#[allow(unused_imports)]
 use super::types::{
     cl_bool, cl_command_queue, cl_command_queue_info, cl_command_queue_properties, cl_context,
     cl_device_id, cl_event, cl_int, cl_kernel, cl_map_flags, cl_mem, cl_mem_migration_flags,
     cl_queue_properties, cl_uint, cl_ulong,
 };
 use super::{api_info_size, api_info_value, api_info_vector};
-#[allow(unused_imports)]
 use cl_sys::{
-    clCreateCommandQueue, clCreateCommandQueueWithProperties, clEnqueueBarrierWithWaitList,
-    clEnqueueCopyBuffer, clEnqueueCopyBufferRect, clEnqueueCopyBufferToImage, clEnqueueCopyImage,
-    clEnqueueCopyImageToBuffer, clEnqueueFillBuffer, clEnqueueFillImage, clEnqueueMapBuffer,
-    clEnqueueMapImage, clEnqueueMarkerWithWaitList, clEnqueueMigrateMemObjects,
+    clCreateCommandQueue, clEnqueueCopyBuffer, clEnqueueCopyBufferRect, clEnqueueCopyBufferToImage,
+    clEnqueueCopyImage, clEnqueueCopyImageToBuffer, clEnqueueMapBuffer, clEnqueueMapImage,
     clEnqueueNDRangeKernel, clEnqueueNativeKernel, clEnqueueReadBuffer, clEnqueueReadBufferRect,
-    clEnqueueReadImage, clEnqueueSVMFree, clEnqueueSVMMap, clEnqueueSVMMemFill, clEnqueueSVMMemcpy,
-    clEnqueueSVMMigrateMem, clEnqueueSVMUnmap, clEnqueueTask, clEnqueueUnmapMemObject,
-    clEnqueueWriteBuffer, clEnqueueWriteBufferRect, clEnqueueWriteImage, clFinish, clFlush,
-    clGetCommandQueueInfo, clReleaseCommandQueue, clRetainCommandQueue,
+    clEnqueueReadImage, clEnqueueUnmapMemObject, clEnqueueWriteBuffer, clEnqueueWriteBufferRect,
+    clEnqueueWriteImage, clFinish, clFlush, clGetCommandQueueInfo, clReleaseCommandQueue,
+    clRetainCommandQueue,
 };
+#[cfg(feature = "CL_VERSION_1_2")]
+use cl_sys::{
+    clEnqueueBarrierWithWaitList, clEnqueueFillBuffer, clEnqueueFillImage,
+    clEnqueueMarkerWithWaitList, clEnqueueMigrateMemObjects, clEnqueueTask,
+};
+#[cfg(feature = "CL_VERSION_2_0")]
+use cl_sys::{
+    clCreateCommandQueueWithProperties, clEnqueueSVMFree, clEnqueueSVMMap, clEnqueueSVMMemFill,
+    clEnqueueSVMMemcpy, clEnqueueSVMUnmap,
+};
+#[cfg(feature = "CL_VERSION_2_1")]
+use cl_sys::clEnqueueSVMMigrateMem;
 
 use libc::{c_void, intptr_t, size_t};
 use std::mem;
@@ -57,7 +66,6 @@ use std::ptr;
 ///
 /// returns a Result containing the new OpenCL command-queue
 /// or the error code from the OpenCL C API function.
-#[cfg(feature = "CL_VERSION_1_2")]
 #[inline]
 pub fn create_command_queue(
     context: cl_context,
@@ -143,7 +151,7 @@ pub fn get_command_queue_data(
     api_info_size!(get_size, clGetCommandQueueInfo);
     let size = get_size(command_queue, param_name)?;
     api_info_vector!(get_vector, u8, clGetCommandQueueInfo);
-    Ok(get_vector(command_queue, param_name, size)?)
+    get_vector(command_queue, param_name, size)
 }
 
 // cl_command_queue_info
@@ -392,6 +400,7 @@ pub fn enqueue_write_buffer_rect(
     }
 }
 
+#[cfg(feature = "CL_VERSION_1_2")]
 #[inline]
 pub fn enqueue_fill_buffer(
     command_queue: cl_command_queue,
@@ -568,6 +577,7 @@ pub fn enqueue_write_image(
     }
 }
 
+#[cfg(feature = "CL_VERSION_1_2")]
 #[inline]
 pub fn enqueue_fill_image(
     command_queue: cl_command_queue,
@@ -798,6 +808,7 @@ pub fn enqueue_unmap_mem_object(
     }
 }
 
+#[cfg(feature = "CL_VERSION_1_2")]
 #[inline]
 pub fn enqueue_migrate_mem_object(
     command_queue: cl_command_queue,
@@ -918,6 +929,7 @@ pub fn enqueue_native_kernel(
     }
 }
 
+#[cfg(feature = "CL_VERSION_1_2")]
 #[inline]
 pub fn enqueue_marker_with_wait_list(
     command_queue: cl_command_queue,
@@ -940,6 +952,7 @@ pub fn enqueue_marker_with_wait_list(
     }
 }
 
+#[cfg(feature = "CL_VERSION_1_2")]
 #[inline]
 pub fn enqueue_barrier_with_wait_list(
     command_queue: cl_command_queue,
@@ -962,6 +975,7 @@ pub fn enqueue_barrier_with_wait_list(
     }
 }
 
+#[cfg(feature = "CL_VERSION_2_0")]
 #[inline]
 pub fn enqueue_svm_free(
     command_queue: cl_command_queue,
@@ -999,6 +1013,7 @@ pub fn enqueue_svm_free(
     }
 }
 
+#[cfg(feature = "CL_VERSION_2_0")]
 #[inline]
 pub fn enqueue_svm_mem_cpy(
     command_queue: cl_command_queue,
@@ -1029,6 +1044,7 @@ pub fn enqueue_svm_mem_cpy(
     }
 }
 
+#[cfg(feature = "CL_VERSION_2_0")]
 #[inline]
 pub fn enqueue_svm_mem_fill(
     command_queue: cl_command_queue,
@@ -1059,6 +1075,7 @@ pub fn enqueue_svm_mem_fill(
     }
 }
 
+#[cfg(feature = "CL_VERSION_2_0")]
 #[inline]
 pub fn enqueue_svm_map(
     command_queue: cl_command_queue,
@@ -1089,6 +1106,7 @@ pub fn enqueue_svm_map(
     }
 }
 
+#[cfg(feature = "CL_VERSION_2_0")]
 #[inline]
 pub fn enqueue_svm_unmap(
     command_queue: cl_command_queue,
@@ -1144,14 +1162,13 @@ pub fn enqueue_svm_migrate_mem(
     }
 }
 
-
 #[cfg(test)]
 mod tests {
     use super::*;
     use crate::context::{create_context, release_context};
     use crate::device::{get_device_ids, CL_DEVICE_TYPE_GPU};
-    use crate::platform::get_platform_ids;
     use crate::error_codes::error_text;
+    use crate::platform::get_platform_ids;
 
     #[test]
     fn test_command_queue() {
@@ -1168,8 +1185,12 @@ mod tests {
         let context = create_context(&device_ids, ptr::null(), None, ptr::null_mut());
         let context = context.unwrap();
 
-        let queue = create_command_queue(context, device_id,
-            CL_QUEUE_PROFILING_ENABLE | CL_QUEUE_OUT_OF_ORDER_EXEC_MODE_ENABLE).unwrap();
+        let queue = create_command_queue(
+            context,
+            device_id,
+            CL_QUEUE_PROFILING_ENABLE | CL_QUEUE_OUT_OF_ORDER_EXEC_MODE_ENABLE,
+        )
+        .unwrap();
 
         let value = get_command_queue_info(queue, CommandQueueInfo::CL_QUEUE_CONTEXT).unwrap();
         let value = value.to_ptr();
@@ -1181,7 +1202,8 @@ mod tests {
         println!("CL_QUEUE_DEVICE: {:X}", value);
         assert_eq!(device_id, value as cl_device_id);
 
-        let value = get_command_queue_info(queue, CommandQueueInfo::CL_QUEUE_REFERENCE_COUNT).unwrap();
+        let value =
+            get_command_queue_info(queue, CommandQueueInfo::CL_QUEUE_REFERENCE_COUNT).unwrap();
         let value = value.to_uint();
         println!("CL_QUEUE_REFERENCE_COUNT: {}", value);
         assert_eq!(1, value);
@@ -1196,7 +1218,7 @@ mod tests {
                 let value = value.to_uint();
                 println!("CL_QUEUE_SIZE: {}", value);
             }
-            Err(e) => println!("OpenCL error, CL_QUEUE_SIZE: {}", error_text(e))
+            Err(e) => println!("OpenCL error, CL_QUEUE_SIZE: {}", error_text(e)),
         };
 
         // CL_VERSION_2_1 value
@@ -1205,20 +1227,20 @@ mod tests {
                 let value = value.to_ptr();
                 println!("CL_QUEUE_DEVICE_DEFAULT: {:X}", value);
             }
-            Err(e) => println!("OpenCL error, CL_QUEUE_DEVICE_DEFAULT: {}", error_text(e))
+            Err(e) => println!("OpenCL error, CL_QUEUE_DEVICE_DEFAULT: {}", error_text(e)),
         };
-        
+
         // CL_VERSION_3_0 value
         match get_command_queue_info(queue, CommandQueueInfo::CL_QUEUE_PROPERTIES_ARRAY) {
             Ok(value) => {
                 let value = value.to_vec_ulong();
                 println!("CL_QUEUE_PROPERTIES_ARRAY: {}", value.len());
             }
-            Err(e) => println!("OpenCL error, CL_QUEUE_PROPERTIES_ARRAY: {}", error_text(e))
+            Err(e) => println!("OpenCL error, CL_QUEUE_PROPERTIES_ARRAY: {}", error_text(e)),
         };
-        
+
         release_command_queue(queue).unwrap();
 
         release_context(context).unwrap();
     }
-}
\ No newline at end of file
+}
