@@ -61,13 +61,14 @@ use super::ffi::cl_ext::{cl_amd_device_topology, cl_device_pci_bus_info_khr,
     CL_DEVICE_LUID_KHR, CL_DEVICE_NODE_MASK_KHR,
 };
 use super::{api_info_size, api_info_value, api_info_vector};
-#[allow(unused_imports)]
-use cl_sys::{
-    clCreateSubDevices, clGetDeviceIDs, clGetDeviceInfo, clReleaseDevice, clRetainDevice, 
-    clSetDefaultDeviceCommandQueue, 
-};
+use cl_sys::{clGetDeviceIDs, clGetDeviceInfo};
+#[cfg(feature = "CL_VERSION_1_2")]
+use cl_sys::{clCreateSubDevices, clReleaseDevice, clRetainDevice};
+#[cfg(feature = "CL_VERSION_2_1")]
+use cl_sys::clSetDefaultDeviceCommandQueue;
 
 // clGetDeviceAndHostTimer, clGetHostTimer, are incorrect in cl_sys
+#[cfg(feature = "CL_VERSION_2_1")]
 #[cfg_attr(not(target_os = "macos"), link(name = "OpenCL"))]
 #[cfg_attr(target_os = "macos", link(name = "OpenCL", kind = "framework"))]
 extern "system" {
@@ -158,30 +159,28 @@ pub fn get_device_ids(
 
     if (CL_SUCCESS != status) && (CL_DEVICE_NOT_FOUND != status) {
         Err(status)
-    } else {
-        if 0 < count {
-            // Get the device ids.
-            let len = count as usize;
-            let mut ids: Vec<cl_device_id> = Vec::with_capacity(len);
-            unsafe {
-                ids.set_len(len);
-                status = clGetDeviceIDs(
-                    platform,
-                    device_type,
-                    count,
-                    ids.as_mut_ptr(),
-                    ptr::null_mut(),
-                );
-            };
+    } else if 0 < count {
+        // Get the device ids.
+        let len = count as usize;
+        let mut ids: Vec<cl_device_id> = Vec::with_capacity(len);
+        unsafe {
+            ids.set_len(len);
+            status = clGetDeviceIDs(
+                platform,
+                device_type,
+                count,
+                ids.as_mut_ptr(),
+                ptr::null_mut(),
+            );
+        };
 
-            if CL_SUCCESS != status {
-                Err(status)
-            } else {
-                Ok(ids)
-            }
+        if CL_SUCCESS != status {
+            Err(status)
         } else {
-            Ok(Vec::default())
+            Ok(ids)
         }
+    } else {
+        Ok(Vec::default())
     }
 }
 
@@ -194,7 +193,7 @@ pub fn get_device_data(
     api_info_size!(get_size, clGetDeviceInfo);
     let size = get_size(device, param_name)?;
     api_info_vector!(get_vector, u8, clGetDeviceInfo);
-    Ok(get_vector(device, param_name, size)?)
+    get_vector(device, param_name, size)
 }
 
 // cl_device_info
@@ -505,7 +504,7 @@ pub fn get_device_info(device: cl_device_id, param_name: DeviceInfo) -> Result<I
         | DeviceInfo::CL_DEVICE_GPU_OVERLAP_NV // cl_nv_device_attribute_query
         | DeviceInfo::CL_DEVICE_KERNEL_EXEC_TIMEOUT_NV // cl_nv_device_attribute_query
         | DeviceInfo::CL_DEVICE_INTEGRATED_MEMORY_NV // cl_nv_device_attribute_query
-       
+
         | DeviceInfo::CL_DEVICE_PCI_BUS_ID_NV // cl_nv_device_attribute_query, undocumented
         | DeviceInfo::CL_DEVICE_PCI_SLOT_ID_NV // cl_nv_device_attribute_query, undocumented
 
@@ -563,7 +562,7 @@ pub fn get_device_info(device: cl_device_id, param_name: DeviceInfo) -> Result<I
         | DeviceInfo::CL_DEVICE_MAX_GLOBAL_VARIABLE_SIZE
         | DeviceInfo::CL_DEVICE_QUEUE_ON_DEVICE_PREFERRED_SIZE
         | DeviceInfo::CL_DEVICE_QUEUE_ON_DEVICE_MAX_SIZE
-        | DeviceInfo::CL_DEVICE_GLOBAL_VARIABLE_PREFERRED_TOTAL_SIZE 
+        | DeviceInfo::CL_DEVICE_GLOBAL_VARIABLE_PREFERRED_TOTAL_SIZE
         | DeviceInfo::CL_DEVICE_PREFERRED_WORK_GROUP_SIZE_MULTIPLE // CL_VERSION_3_0
         | DeviceInfo::CL_DEVICE_PROFILING_TIMER_OFFSET_AMD // cl_amd_device_attribute_query
         | DeviceInfo::CL_DEVICE_GLOBAL_FREE_MEMORY_AMD // cl_amd_device_attribute_query
@@ -603,7 +602,7 @@ pub fn get_device_info(device: cl_device_id, param_name: DeviceInfo) -> Result<I
         // CL_VERSION_3_0
         DeviceInfo::CL_DEVICE_EXTENSIONS_WITH_VERSION
         | DeviceInfo::CL_DEVICE_ILS_WITH_VERSION
-        | DeviceInfo::CL_DEVICE_BUILT_IN_KERNELS_WITH_VERSION 
+        | DeviceInfo::CL_DEVICE_BUILT_IN_KERNELS_WITH_VERSION
         | DeviceInfo::CL_DEVICE_OPENCL_C_ALL_VERSIONS
         | DeviceInfo::CL_DEVICE_OPENCL_C_FEATURES => {
             api_info_vector!(get_vec, cl_name_version, clGetDeviceInfo);
@@ -622,7 +621,7 @@ pub fn get_amd_device_topology(bytes: &[u8]) -> cl_amd_device_topology {
     let mut topology = cl_amd_device_topology::default();
     unsafe {
         std::slice::from_raw_parts_mut(&mut topology as *mut cl_amd_device_topology as *mut u8, size)
-            .copy_from_slice(&bytes);
+            .copy_from_slice(bytes);
     }
     topology
 }
@@ -634,7 +633,7 @@ pub fn get_device_pci_bus_info_khr(bytes: &[u8]) -> cl_device_pci_bus_info_khr {
     let mut pci_bus_info = cl_device_pci_bus_info_khr::default();
     unsafe {
         std::slice::from_raw_parts_mut(&mut pci_bus_info as *mut cl_device_pci_bus_info_khr as *mut u8, size)
-            .copy_from_slice(&bytes);
+            .copy_from_slice(bytes);
     }
     pci_bus_info
 }
@@ -646,6 +645,7 @@ pub const CL_DEVICE_PARTITION_BY_COUNTS_LIST_END: cl_device_partition_property =
 pub const CL_DEVICE_PARTITION_BY_AFFINITY_DOMAIN: cl_device_partition_property = 0x1088;
 
 // helper function for create_sub_devices
+#[cfg(feature = "CL_VERSION_1_2")]
 #[inline]
 fn count_sub_devices(
     in_device: cl_device_id,
@@ -677,6 +677,7 @@ fn count_sub_devices(
 ///
 /// returns a Result containing a vector of available sub-device ids
 /// or the error code from the OpenCL C API function.
+#[cfg(feature = "CL_VERSION_1_2")]
 #[inline]
 pub fn create_sub_devices(
     in_device: cl_device_id,
@@ -712,6 +713,7 @@ pub fn create_sub_devices(
 /// * `device` - the cl_device_id of the OpenCL device.
 ///
 /// returns an empty Result or the error code from the OpenCL C API function.
+#[cfg(feature = "CL_VERSION_1_2")]
 #[inline]
 pub fn retain_device(device: cl_device_id) -> Result<(), cl_int> {
     let status: cl_int = unsafe { clRetainDevice(device) };
@@ -729,6 +731,7 @@ pub fn retain_device(device: cl_device_id) -> Result<(), cl_int> {
 /// * `device` - the cl_device_id of the OpenCL device.
 ///
 /// returns an empty Result or the error code from the OpenCL C API function.
+#[cfg(feature = "CL_VERSION_1_2")]
 #[inline]
 pub fn release_device(device: cl_device_id) -> Result<(), cl_int> {
     let status: cl_int = unsafe { clReleaseDevice(device) };
@@ -1753,6 +1756,7 @@ mod tests {
         assert!(!value.is_empty());
     }
 
+    #[cfg(feature = "CL_VERSION_1_2")]
     #[test]
     fn test_get_sub_devices() {
         let platform_ids = get_platform_ids().unwrap();
